==> haskell-yesod-auth-1.4.19-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.4.19
id: yesod-auth-1.4.19-LkSAuYxZu4jC03zrfJfGjV
key: yesod-auth-1.4.19-LkSAuYxZu4jC03zrfJfGjV
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
author: Michael Snoyman, Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
    Yesod.Auth.Message Yesod.Auth.OpenId Yesod.Auth.Rpxnow
    Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
abi: 059147d9f92907d62e5530423437de92
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-auth-1.4.19
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-auth-1.4.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/yesod-auth-1.4.19
hs-libraries: HSyesod-auth-1.4.19-LkSAuYxZu4jC03zrfJfGjV
depends:
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    authenticate-1.3.3.2-CaQGGxPdXr5ESDkOATG6CG base-4.10.0.0
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm binary-0.8.5.1
    blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7 containers-0.5.10.2
    cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    email-validate-2.3.1-EjdxoskbP1QJJVrkGicaGY
    file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    http-conduit-2.2.3.2-L7IoUqEFXOUA0lK03ykVUK
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ
    mime-mail-0.4.14-IO3NXgp0X4MDTtJcQCjhGb
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    nonce-1.0.4-HXtWCtmcI2eKA3TDmjD8t7
    persistent-2.7.1-6H4sMsn0vpZALFmYSqFMsG
    persistent-template-2.5.3-8YAImMSijXh98xPgteuRZx
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi template-haskell-2.12.0.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    yesod-core-1.4.37-H3gq1KrLSiCD4BHWdk8Tpz
    yesod-form-1.4.16-H6vN86RtCr9DkSaxkXpjdk
    yesod-persistent-1.4.2-5eIVuRFjP9cAM7riD8ii4v
abi-depends: aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=66a2d17fbbc7a6e96ce7fb88add84f33
             authenticate-1.3.3.2-CaQGGxPdXr5ESDkOATG6CG=310d5e81baa71b69c41f5e5bf87138cc
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=8eee912e61521dafabce3d6c55a8e0d0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             binary-0.8.5.1=44e4c28d2f38593047e3772473ecb87e
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=92c6d3f9634de2495e94b00787c1e242
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=7d7fdc10b11e72a088b6791e8c321cca
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=271c22b9b241ac1554c7c5cfd744d37e
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7=3a7b6797885b4f7b0c19a45c8992b33f
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP=2aff2c890f2811a4d19d3ee0bfb54087
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=f7324150b92035ce2f13f55c36f08ab4
             email-validate-2.3.1-EjdxoskbP1QJJVrkGicaGY=2d30099073b73daac5887dbcbb24ea0e
             file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor=ba99223a63c2e21ef45c374192c1b72c
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=92ae31af81259bf85e2a7ae30800ecfd
             http-conduit-2.2.3.2-L7IoUqEFXOUA0lK03ykVUK=e305f9710592fcb57a44dd73aa857615
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=cf58c71914eac1aaf26174fb0607ced0
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=95aa1eec1ee6d97d56ce509d22129a9d
             mime-mail-0.4.14-IO3NXgp0X4MDTtJcQCjhGb=d4191576a17d029af0a48745c0bdf201
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
             nonce-1.0.4-HXtWCtmcI2eKA3TDmjD8t7=c89cb12c8156aee06d59518ede965c87
             persistent-2.7.1-6H4sMsn0vpZALFmYSqFMsG=8ed7581e2414a48d853e585d3915b3bf
             persistent-template-2.5.3-8YAImMSijXh98xPgteuRZx=9fcb689c6f4e13f91c60fe6e3143c872
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=5faba54ff6ceaac5cbd433f5aeb4a970
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=368aa3ad25486678b8f3fef19ec4be32
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=cfc55f2e283380323019b805a0a4216d
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=9c6a864f8fa1a2052bc8fe34ff093e3a
             yesod-core-1.4.37-H3gq1KrLSiCD4BHWdk8Tpz=667fb6776dc52ecdbdee67226f5677df
             yesod-form-1.4.16-H6vN86RtCr9DkSaxkXpjdk=e2eabf37e8d858ca884fd1b677a94240
             yesod-persistent-1.4.2-5eIVuRFjP9cAM7riD8ii4v=016d09aa31b9aaaff7ec8a676d1f1b61
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-auth-1.4.19-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-auth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-auth
version: 1.4.19
id: yesod-auth-1.4.19-FPve3477cJutNf3KTD2Eg
key: yesod-auth-1.4.19-FPve3477cJutNf3KTD2Eg
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>
category: Web, Yesod
author: Michael Snoyman, Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
    Yesod.Auth.Message Yesod.Auth.OpenId Yesod.Auth.Rpxnow
    Yesod.Auth.Util.PasswordStore
hidden-modules: Yesod.Auth.Routes
abi: 3a1c4c3cf569bcc32dfbf7529fec6d66
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-auth-1.4.19
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-auth-1.4.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/yesod-auth-1.4.19
hs-libraries: HSyesod-auth-1.4.19-FPve3477cJutNf3KTD2Eg
depends:
    aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    authenticate-1.3.3.2-D6m6tkawp9WEWDfsj2LKDA base-4.10.0.0
    base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm binary-0.8.5.1
    blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh
    blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7 containers-0.5.10.2
    cryptonite-0.24-K7sWwdWlF3ZAyrdpRtdoRO
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    email-validate-2.3.2-8JwELxlpS5PGCVnGhRCQEs
    file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
    http-client-0.5.7.1-3lJEt29GZp278eofO9V2MK
    http-conduit-2.2.3.2-KXU5qeYhDXV4XB7lmAjRlb
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ
    memory-0.14.8-BAg3DtPwumR3TQfKUohmeR
    mime-mail-0.4.14-IO3NXgp0X4MDTtJcQCjhGb
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    nonce-1.0.4-HXtWCtmcI2eKA3TDmjD8t7
    persistent-2.7.1-6H4sMsn0vpZALFmYSqFMsG
    persistent-template-2.5.3-8YAImMSijXh98xPgteuRZx
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi template-haskell-2.12.0.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    yesod-core-1.4.37-EBGkF6t8tgdJwj9XkY4HV0
    yesod-form-1.4.16-BwSc5VoWQDY6FbHQsBpXoa
    yesod-persistent-1.4.2-7XzHtLXrljaDR6iZhsZPVU
abi-depends: aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=66a2d17fbbc7a6e96ce7fb88add84f33
             authenticate-1.3.3.2-D6m6tkawp9WEWDfsj2LKDA=8166f7b836f74d81455776b2c44aade3
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=8eee912e61521dafabce3d6c55a8e0d0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             binary-0.8.5.1=44e4c28d2f38593047e3772473ecb87e
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=92c6d3f9634de2495e94b00787c1e242
             blaze-html-0.9.0.1-kPi4af1DH04kfw48f7OOh=7d7fdc10b11e72a088b6791e8c321cca
             blaze-markup-0.8.0.0-FzqDX3sF5iY7olwigbNHfL=271c22b9b241ac1554c7c5cfd744d37e
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7=3a7b6797885b4f7b0c19a45c8992b33f
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             cryptonite-0.24-K7sWwdWlF3ZAyrdpRtdoRO=9573bf3c543b458d8ee9733176e7c149
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=f7324150b92035ce2f13f55c36f08ab4
             email-validate-2.3.2-8JwELxlpS5PGCVnGhRCQEs=14005b67a87c13bbc5f75d269eeb803e
             file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor=ba99223a63c2e21ef45c374192c1b72c
             http-client-0.5.7.1-3lJEt29GZp278eofO9V2MK=3365d8e30e82e500d109a3f5c7a7d08f
             http-conduit-2.2.3.2-KXU5qeYhDXV4XB7lmAjRlb=7409c30e8b60dfeca707af0f25c8a82f
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             lifted-base-0.2.3.11-KDN0Y8mQMJ08XWJafJpKLJ=cf58c71914eac1aaf26174fb0607ced0
             memory-0.14.8-BAg3DtPwumR3TQfKUohmeR=d910bbee9f7131c0d1070631b55ccda1
             mime-mail-0.4.14-IO3NXgp0X4MDTtJcQCjhGb=d4191576a17d029af0a48745c0bdf201
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
             nonce-1.0.4-HXtWCtmcI2eKA3TDmjD8t7=c89cb12c8156aee06d59518ede965c87
             persistent-2.7.1-6H4sMsn0vpZALFmYSqFMsG=8ed7581e2414a48d853e585d3915b3bf
             persistent-template-2.5.3-8YAImMSijXh98xPgteuRZx=9fcb689c6f4e13f91c60fe6e3143c872
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=5faba54ff6ceaac5cbd433f5aeb4a970
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=368aa3ad25486678b8f3fef19ec4be32
             shakespeare-2.0.14-ILbjPbZM5dUCAePhfgNGCi=cfc55f2e283380323019b805a0a4216d
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=9c6a864f8fa1a2052bc8fe34ff093e3a
             yesod-core-1.4.37-EBGkF6t8tgdJwj9XkY4HV0=8aec100ebd97108f54bc594e98ad2291
             yesod-form-1.4.16-BwSc5VoWQDY6FbHQsBpXoa=518b94e65cad06737b1e177be46205c0
             yesod-persistent-1.4.2-7XzHtLXrljaDR6iZhsZPVU=cb48ab3f7f597c2720bb26bc0bf55c1a
haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html: /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
